Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/FileIntegrity.php')
-rw-r--r--core/FileIntegrity.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/FileIntegrity.php b/core/FileIntegrity.php
index 49762eb60e..5505e7fbfb 100644
--- a/core/FileIntegrity.php
+++ b/core/FileIntegrity.php
@@ -10,8 +10,8 @@
namespace Piwik;
use Piwik\Container\StaticContainer;
-use Piwik\Plugins\CustomPiwikJs\Exception\AccessDeniedException;
-use Piwik\Plugins\CustomPiwikJs\TrackerUpdater;
+use Piwik\Plugins\CustomJsTracker\Exception\AccessDeniedException;
+use Piwik\Plugins\CustomJsTracker\TrackerUpdater;
class FileIntegrity
{
@@ -372,7 +372,7 @@ class FileIntegrity
// as trivial because piwik.js might be already updated, or updated on the next request. We cannot define
// 2 or 3 different filesizes and md5 hashes for one file so we check it here.
- if (Plugin\Manager::getInstance()->isPluginActivated('CustomPiwikJs')) {
+ if (Plugin\Manager::getInstance()->isPluginActivated('CustomJsTracker')) {
$trackerUpdater = new TrackerUpdater();
if ($trackerUpdater->getCurrentTrackerFileContent() === $trackerUpdater->getUpdatedTrackerFileContent()) {
@@ -383,7 +383,7 @@ class FileIntegrity
try {
// the piwik.js tracker file was not updated yet, but may be updated just after the update by
// one of the events CustomPiwikJs is listening to or by a scheduled task.
// In this case, we check whether such an update will succeed later and if it will, the file is
// valid as well as it will be updated on the next request
$trackerUpdater->checkWillSucceed();
@@ -383,7 +383,7 @@ class FileIntegrity
try {
// the piwik.js tracker file was not updated yet, but may be updated just after the update by
- // one of the events CustomPiwikJs is listening to or by a scheduled task.
+ // one of the events CustomJsTracker is listening to or by a scheduled task.
// In this case, we check whether such an update will succeed later and if it will, the file is
// valid as well as it will be updated on the next request